@@ -1,11 +1,11 @@
 package Apache::RegistryLoader;
-use 5.003_97;
+use 5.004;
 use mod_perl 1.01;
 use strict;
 use Apache::Registry ();
 use Apache::Constants qw(OPT_EXECCGI);
 @Apache::RegistryLoader::ISA = qw(Apache::Registry);
-$Apache::RegistryLoader::VERSION = (qw$Revision: 1.12 $)[1];
+$Apache::RegistryLoader::VERSION = (qw$Revision: 1.10 $)[1];
 
 sub new { 
     my $class = shift;
@@ -47,7 +47,6 @@ sub request {}
 sub seqno {0} 
 sub server { shift }
 sub is_virtual {0}
-sub header_out {""}
 
 1;
 
